import React from 'react';
import type { ColumnType, OptionType, OptionsType, Theme, Labels } from '../../types';
interface ContainerProps {
    /**
     * The component labels.
     */
    labels: Labels;
    /**
     * The currently selected option.
     */
    current: OptionType;
    /**
     * The function to set the current option.
     */
    select: (option: OptionType) => void;
    /**
     * The function to select an option.
     */
    add: () => void;
    /**
     * The function to remove a selected option.
     */
    remove: () => void;
    /**
     * The function to select all options.
     */
    addAll: () => void;
    /**
     * The function to remove all selected options.
     */
    removeAll: () => void;
    /**
     * The available select options.
     */
    options: OptionsType;
    /**
     * The selected options.
     */
    selected: OptionsType;
    /**
     * Truthy if the selected options >= max allowed options.
     */
    isMax: boolean;
    /**
     * Disables the "add all" button if the available options > max allowed options.
     */
    disableAddAll: boolean;
    /**
     * The function to go to next option.
     */
    onNext: (column: ColumnType) => void;
    /**
     * The function to go to previous option.
     */
    onPrevious: (column: ColumnType) => void;
    /**
     * Enable to make the columns searchable.
     */
    isSearchable?: boolean;
    /**
     * Disable the "Add All" and "Remove All" buttons.
     * @default false
     */
    disableAllButtons?: boolean;
    /**
     * Disable double clicking to add/remove a list option.
     */
    disableDoubleClick?: boolean;
    /**
     * Disable keyboard navigation between list options.
     */
    disableKeyboard?: boolean;
    /**
     * The react-column-select theme object.
     */
    theme: Theme;
}
declare const Container: React.FC<ContainerProps>;
export default Container;
